# Supplemental Information: Ion-Aerosol Flux Coefficients and the Steady State Charge Distribution of Aerosols in a Bipolar Ion Environment, doi: 10.1080/02786826.2013.783684

This table lists text file names included in the supplemental files
besides a description of their contents. Each row in a text file contains
the particle charge described by the fit followed by the 12 ($I=11$),
or 24 ($I=23$) for flux coefficients, fit coefficients, $B_{i}(k)$,
the minimum relative error of the fit, the maximum relative error
of the fit, and the minimum and maximum radii (in meters) over which
the fit is valid. The curves are generated by using these coefficients
in this formula:

$$g(k)=10^{\Sigma_{i=0}^{I}B_{i}(k)(\log_{10}(a_{p}))^i}$$

where $k$ is the charge state, and $a_p$ is the radius of the particle
in meters.

| File | Description |
| - | - |
| S1 | Flux Coefficients for negative "air" ions to conductive particles where $\beta_{k,i}\geq10^{-15}$ at 101325 Pa and 298.15 K. |
| S2 | Flux Coefficients for positive "air" ions to conductive particles where $\beta_{k,i}\geq10^{-15}$ at 101325 Pa and 298.15 K. |
| S3 | Steady State distribution for "air" ions and conductive particles where $\frac{N_{k}}{Z}\geq10^{-5}$ at 101325 Pa and 298.15 K.|
| S4 | Flux Coefficients for negative water ions to conductive particles where $\beta_{k,i}\geq10^{-15}$ at 101325 Pa and 298.15 K. |
| S5 | Flux Coefficients for positive water ions to conductive particles where $\beta_{k,i}\geq10^{-15}$ at 101325 Pa and 298.15 K. |
| S6 | Steady State distribution for water ions and conductive particles where $\frac{N_{k}}{Z}\geq10^{-5}$ at 101325 Pa and 298.15 K. |
| S7 | Flux Coefficients for negative "air" ions to conductive particles where $\beta_{k,i}\geq10^{-15}$ at 4480 Pa and 218.15 K. |
S8 | Flux Coefficients for positive "air" ions to conductive particles  where $\beta_{k,i}\geq10^{-15}$ at 4480 Pa and 218.15 K. |
S9 | Steady State distribution for "air" ions and conductive particles  where $\frac{N_{k}}{Z}\geq10^{-5}$ at 4480 Pa and 218.15 K. |
S10 | Flux Coefficients for negative water ions to conductive particles  where $\beta_{k,i}\geq10^{-15}$ at 4480 Pa and 218.15 K.  |
S11 | Flux Coefficients for positive water ions to conductive particles  where $\beta_{k,i}\geq10^{-15}$ at at 4480 Pa and 218.15 K. |
S12 | Steady State distribution for water ions and conductive particles  where $\frac{N_{k}}{Z}\geq10^{-5}$ at at 4480 Pa and 218.15 K. |
S13 | Flux Coefficients for negative "air" ions to polystyrene particles  where $\beta_{k,i}\geq10^{-15}$ at 101325 Pa and 298.15 K. |
S14 | Flux Coefficients for positive "air" ions to polystyrene particles  where $\beta_{k,i}\geq10^{-15}$ at 101325 Pa and 298.15 K. |
S15 | Steady State distribution for "air" ions and polystyrene particles  where $\frac{N_{k}}{Z}\geq10^{-5}$ at 101325 Pa and 298.15 K. |
